@@ -15,6 +15,8 @@ from .__version import __version__
 LOG_LEVELS = ["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]
 DEFAULT_LOG_LEVEL = "ERROR"
 
+LOG = logging.getLogger("weconnect-mqtt")
+
 
 class NumberRangeArgument:
 
@@ -96,10 +98,16 @@ def main():  # noqa: C901
         try:
             secrets = netrc.netrc(file=args.netrc)
             username, _, password = secrets.authenticators("volkswagen.de")
+        except TypeError:
+            if not args.username:
+                LOG.error('volkswagen.de entry was not found in .netrc file. Create it or provide at least a username'
+                          ' with --username')
+                sys.exit(1)
+            username = args.username
+            password = getpass.getpass()
         except FileNotFoundError:
             if not args.username:
-                print('.netrc file was not found. Create it or provide at least a username with --username',
-                      file=sys.stderr)
+                LOG.error('.netrc file was not found. Create it or provide at least a username with --username')
                 sys.exit(1)
             username = args.username
             password = getpass.getpass()
@@ -150,7 +158,7 @@ def main():  # noqa: C901
             weConnect.update()
             time.sleep(args.interval)
     else:
-        print('command not implemented', file=sys.stderr)
+        LOG.error('command not implemented')
     if not args.fromcache:
         weConnect.persistTokens()
     if args.cache:
